#
# spec file for package libbsd
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname	libbsd0
Name:           libbsd
Version:        0.8.7
Release:        150600.16.2
Summary:        Provides useful functions commonly found on BSD systems
License:        BSD-3-Clause
Group:          Development/Languages/C and C++
Url:            http://libbsd.freedesktop.org/
#Git-Clone:	git://anongit.freedesktop.org/git/libbsd
#Git-Web:	http://cgit.freedesktop.org/libbsd/
Source0:        https://archive.hadrons.org/software/%{name}/%{name}-%{version}.tar.xz
Source1:        https://archive.hadrons.org/software/%{name}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Patch0:         libbsd-0.8.7-CVE-2019-20367.patch
BuildRequires:  fdupes
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig

%description
This library provides useful functions commonly found on BSD systems, and
lacking on others like GNU systems, thus making it easier to port projects
with strong BSD origins, without needing to embed the same code over and
over again on each project.

%package -n %{lname}
Summary:        Provides useful functions commonly found on BSD systems
Group:          System/Libraries

%description -n %{lname}
This library provides useful functions commonly found on BSD systems, and
lacking on others like GNU systems, thus making it easier to port projects
with strong BSD origins, without needing to embed the same code over and
over again on each project.

%package devel
Summary:        Development headers and files for libbsd
Group:          Development/Languages/C and C++
Requires:       %{lname} = %{version}
Requires:       glibc-devel

%description devel
This library provides useful functions commonly found on BSD systems, and
lacking on others like GNU systems, thus making it easier to port projects
with strong BSD origins, without needing to embed the same code over and
over again on each project.

%package ctor-static
Summary:        Development headers and files for libbsd
Group:          Development/Languages/C and C++
Requires:       %{lname} = %{version}-%{release}
Requires:       pkgconfig

%description ctor-static
The libbsd-ctor static library is required if setproctitle() is to be used
when libbsd is loaded via dlopen() from a threaded program.  This can be
configured using "pkg-config --libs libbsd-ctor".

%prep
%setup -q
%patch0 -p1

%build
%configure \
	--disable-static \
	--with-pic
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes -s  %{buildroot}

%check
make %{?_smp_mflags} check

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%doc ChangeLog COPYING
%{_libdir}/libbsd.so.0*

%files devel
%{_includedir}/bsd
%{_libdir}/libbsd.so
%{_mandir}/man3/*
%{_mandir}/man7/*
%{_libdir}/pkgconfig/libbsd.pc
%{_libdir}/pkgconfig/libbsd-overlay.pc

%files ctor-static
%{_libdir}/libbsd-ctor.a
%{_libdir}/pkgconfig/libbsd-ctor.pc

%changelog
* Mon Jan 13 2020 mvetter@suse.com
- bsc#1160551 (CVE-2019-20367):
  Fix out-of-bounds read during a comparison for a symbol name
  from the string table.
- Add libbsd-0.8.7-CVE-2019-20367.patch
* Wed Jan 24 2018 avindra@opensuse.org
- Update to version 0.8.7:
  * Fix <sys/cdefs.h> for gcc with no __has_include or
    __has_include_next support
  * man: Document on what other BSDs arc4random(3) is present
  * Handle several functions now being provided by glibc
  * test: Fix nlist(3) unit test on IA64
- switch to mirror temporarily, per announce:
  https://lists.freedesktop.org/archives/libbsd/2018-January/000166.html
* Thu Oct 19 2017 mpluskal@suse.com
- Update to version 0.8.6:
  * test:
    + Fix nlist() unit test on IA64 and PowerPC 64-bit ELFv1
  * Fix handling of non-contiguous argv + envp in setproctitle()
- Changes for version 0.8.5:
  * test:
    + Handle libtool executable names in getprogname() unit test
    + Remove unused variable in nlist() unit test
  * man:
    + Ship and install libbsd(7)
    + Update man page sections in titles and references
  * Fix ELF definitions for PowerPC in local-elf.h
  * Fix ELF definitions for MIPS in local-elf.h
- Changes for version 0.8.4:
  * Add support for RISC-V
  * Support GCC deprecated attribute for GCC older than 4.5
  * Fix the __progname check to avoid the optimizer discarding the symbol
  * Gracefully handle lack of system <sys/cdefs.h>
  * Do not provide funopen() on musl
  * Try <linux/a.out.h> if <a.out.h> is not present
  * Do not use legacy BSD u_* types
  * Import <sys/time.h> for some of its macros
* Tue May 17 2016 mpluskal@suse.com
- Update to version 0.8.3:
  * Fix unportable sizeof() usage
  * Fix file descriptor leak in HASHFileChunk helper
  * Switch URLs from http or git to https
  * build: Support clock_gettime() provided in librt
  * man: Fix ungrammatical construct
  * test: Add a unit test for md5
  * Add missing <fcntl.h> includes
- Changes for 0.8.2:
  * test: Fix success return code for arc4random unit test
  * test: Add missing <sys/stat.h> include
  * Fix heap buffer overflow in fgetwln()
  * test: Fix race condition in headers-*.sh
- Enable internal tests
- Use correct package categories
* Mon Dec 28 2015 idonmez@suse.com
- Split static library into libbsd-ctor-static package.
* Sat Dec 26 2015 mpluskal@suse.com
- Update to 0.8.1
  * Use local SHA512 header
  * Unify most arc4random Unix hooks into a single file
  * Add support for GNU/kFreeBSD for closefrom() and getentropy()
  * Fix getentropy implementation to use the correct system hooks
  * Add missing copyright and license headers
  * Relicense my contribution to BSD-2-clause
  * Switch COPYING to Debian copyright machine readable format 1.0
  * Use the non-overlayed libbsd headers when we need our own definitions
  * Add missing include to <md5.h>
  * Turn <bsd/bsd.h> inert when using LIBBSD_OVERLAY
  * test: Add new unit tests for individual headers usage
  * Add support for GNU/Hurd to getentropy()
* Wed Dec  9 2015 mpluskal@suse.com
- Update to 0.8.0
  * See attached ChangeLog for details
* Fri May  8 2015 mpluskal@suse.com
- Add gpg signature
- Use fdupes to remove duplicate files
- Cleanup spec file with spec-cleaner
* Thu Oct 30 2014 dhall@wustl.edu
- update to version 0.7.0
* Thu Sep  6 2012 jengelh@inai.de
- Avoid unnecessary complex install line on Redhatish
- Compact file list, add helpful URLs to specfile
* Thu Sep  6 2012 idonmez@suse.com
- Fix installation on SLE
* Mon Aug 20 2012 crrodriguez@opensuse.org
- Version 0.4.2, swithes to autoconf build system.
* Fri Feb 17 2012 crrodriguez@opensuse.org
- Cleanup spec file for factory submission
* Wed Feb  1 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Fri Oct 21 2011 crrodriguez@opensuse.org
- Fix missing headers, bug in spec file [bnc#725800]
* Tue Aug  2 2011 crrodriguez@opensuse.org
- Update to version 0.3.0
* Fri Jul 30 2010 cristian.rodriguez@opensuse.org
- update to version 0.2.0
* Tue Sep 15 2009 crrodriguez@suse.de
-  update to version 0.1.6
* Sun Jan  4 2009 crrodriguez@suse.de
- first package version
